collect_writes

Function collect_writes 

fn collect_writes<'gcx>(
    gcx: Gcx<'gcx>,
    stmts: impl IntoIterator<Item = &'gcx Stmt<'gcx>>,
    out: &mut Vec<VariableId>,
)
The variables a statement list writes through expressions, nested loops included: assignments (tuple targets included), increments, decrements and deletes. Member and indexed targets do not write their base variable.