is_enumerable_set_value

Function is_enumerable_set_value 

fn is_enumerable_set_value<'hir>(
    gcx: Gcx<'hir>,
    hir: &'hir Hir<'hir>,
    receiver: &Expr<'_>,
) -> bool
Whether receiver is a value of one of the set struct types declared in a library (or contract) named EnumerableSet (AddressSet / UintSet / Bytes32Set), which tells the bound method form apart from the library-qualified form.