fn collect_writes<'gcx>(
gcx: Gcx<'gcx>,
stmts: impl IntoIterator<Item = &'gcx Stmt<'gcx>>,
out: &mut Vec<VariableId>,
)Expand description
The variables a statement list writes through expressions, nested loops included: assignments (tuple targets included), increments, decrements and deletes. Member and indexed targets do not write their base variable.