fn paths_alias(removed: &Option<SetPath>, iterated: &Option<SetPath>) -> boolExpand description
Whether two set operands can name the same set. Two paths that can be read name the same set exactly when they are equal; a path that cannot be read may be either.